==> nextcloud-24.0.10.tgz: nextcloud/apps/files/l10n/ka_GE.js <==
OC.L10N.register(
    "files",
    {
    "File could not be found" : "ფაილი ვერ იქნა ნაპოვნი",
    "Move or copy" : "გადაიტანეთ ან დააკოპირეთ",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "წაშლა",
    "Tags" : "ტეგები",
    "Home" : "სახლი",
    "Close" : "დახურვა",
    "Favorites" : "რჩეულები",
    "Could not create folder \"{dir}\"" : "დირექტორია \"{dir}\" ვერ შეიქმნა",
    "Upload cancelled." : "ატვირთვა შეჩერებულ იქნა.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "შეუძლებელია {filename}-ის ატვირთვა, რადგანაც ის დირექტორიაა ან გააჩნია 0 ბაიტი",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "არასაკმარისი თავისუფალი სივრცე, თქვენ ტვირთავთ {size1}-ს, მაგრამ მხოლოდ {size2}-ია დარჩენილი",
    "Target folder \"{dir}\" does not exist any more" : "დანიშნულების დირექტორია \"{dir}\" აღარ არსებობს",
    "Not enough free space" : "არასაკმარისი თავისუფალი სივრცე",
    "Uploading …" : "იტვირთება ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} სულ {totalSize}-დან ({bitrate})",
    "Target folder does not exist any more" : "დანიშნულების დირექტორია აღარ არსებობს",
    "Error when assembling chunks, status code {status}" : "ნაჭრების შეგროვებისას წარმოიშვა შეცდომა, სტატუსის კოდი {status}",
    "Actions" : "მოქმედებები",
    "Rename" : "გადარქმევა",
    "Move" : "გადატანა",
    "Copy" : "კოპირება",
    "Delete file" : "გაუქმდეს ფაილი",
    "Delete folder" : "დირექტორიის გაუქმება",
    "Disconnect storage" : "საცავის გათიშვა",
    "Could not load info for file \"{file}\"" : "ფაილზე \"{file}\" ინფორმაცია ვერ ჩაიტვირთა",
    "Files" : "ფაილები",
    "Details" : "დეტალები",
    "Pending" : "მოცდის რეჟიმში",
    "Unable to determine date" : "თარიღის დადგენა შეუძლებელია",
    "This operation is forbidden" : "ეს ოპერაცია აკრძალულია",
    "This directory is unavailable, please check the logs or contact the administrator" : "დირექტორია ხელმიუწვდომელია, გთოხვთ შეამოწმოთ ლოგები ან დაუკავშირდეთ ადმინისტრატორს",
    "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
    "Could not move \"{file}\", target exists" : "\"{file}\"-ის გადატანა ვერ მოხერხდა, დანიშნულება არსებობს",
    "Could not move \"{file}\"" : "\"{file}\"-ის გადატანა ვერ მოხერხდა",
    "Could not copy \"{file}\", target exists" : "\"{file}\"-ის კოპირება ვერ მოხერხდა, დანიშნულება არსებობს",
    "Could not copy \"{file}\"" : "\"{file}\"-ის კოპირება ვერ მოხერხდა",
    "Copied {origin} inside {destination}" : "დაკოპირდა {origin} {destionation}-ში",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "დაკოპირდა {origin} და {nbfiles} სხვა ფაილი {destionation}-ში",
    "{newName} already exists" : "{newName} უკვე არსებობს",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" სახელი ვერ შეეცვალა, ის აღარ არსებობს",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "სახელი \"{targetName}\" დირექტორია \"{dir}\"-ში უკვე გამოყენებულია. გთხოვთ აირჩიოთ სხვა სახელი.",
    "Could not rename \"{fileName}\"" : "ფაილს \"{fileName}\" სახელი ვერ შეეცვალა",
    "Could not create file \"{file}\"" : "ფაილი \"{file}\" ვერ შეიქმნა",
    "Could not create file \"{file}\" because it already exists" : "ფაილი \"{file}\" ვერ შეიქმნა, ის უკვე არსებობს",
    "Could not create folder \"{dir}\" because it already exists" : "დირექტორია \"{dir}\" ვერ შეიქმნა, ის უკვე არსებობს",
    "Error deleting file \"{fileName}\"." : "ფიალის \"{fileName}\" წაშლისას წარმოიქმნა შეცდომა.",
    "No search results in other folders for {tag}{filter}{endtag}" : "ძიების შედეგები სხვა დირექტორიებში {tag}{filter}{endtag} არაა",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეცვლილია",
    "_%n folder_::_%n folders_" : ["%n დირექტორია","%n დირექტორია"],
    "_%n file_::_%n files_" : ["%n ფაილი","%n ფაილი"],
    "{dirs} and {files}" : "{dirs} და {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n დამალულის ჩათვლით","%n დამალულის ჩათვლით"],
    "_Uploading %n file_::_Uploading %n files_" : ["ვტვირთავთ %n ფაილს","ვტვირთავთ %n ფაილს"],
    "{used} of {quota} used" : "გამოყენებულია {used} სულ  {quota}-დან",
    "{used} used" : "გამოყენებულია {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" არასწორი ფაილის სახელია.",
    "File name cannot be empty." : "ფაილის სახელი არ შეიძლება იყოს ცარიელი.",
    "\"/\" is not allowed inside a file name." : "\"/\" ფაილის სახელში არაა ნებადართული.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" არაა დაშვებული ფაილის ტიპი",
    "View in folder" : "ჩვენება დირექტორიაში",
    "Path" : "მისამართი",
    "_%n byte_::_%n bytes_" : ["%n ბაიტი","%n ბაიტი"],
    "Favorited" : "დამატებულია რჩეულებში",
    "Favorite" : "რჩეული",
    "Copy direct link (only works for users who have access to this file/folder)" : "დააკოპირეთ პირდაპირი ბმული (მუშაობს მომხმარებლებისთვის, რომელთაც გააჩნიათ წვდომა ამ ფაილის/დირექტორიის მიმართ)",
    "New folder" : "ახალი დირექტორია",
    "Upload file" : "ფაილის ატვირთვა",
    "Recent" : "ახალი",
    "Not favorited" : "არაა დამატებული რჩეულებში",
    "Remove from favorites" : "რჩეულებიდან მოშორება",
    "Add to favorites" : "რჩეულებში დამატება",
    "An error occurred while trying to update the tags" : "ტეგების განახლების მცდელობისას წარმოიშვა შეცდომა",
    "Added to favorites" : "დაემატა რჩეულებში",
    "Removed from favorites" : "ამოიშალა რჩეულებიდან",
    "You added {file} to your favorites" : "თქვენ დაამატეთ {file}-ი რჩეულებში",
    "You removed {file} from your favorites" : "თქვენ ამოშალეთ {file}-ი თქვენი რჩეული ფაილებიდან",
    "File changes" : "ფაილის ცვლილებები",
    "Created by {user}" : "შექმნა მომხმარებელმა {user}",
    "Changed by {user}" : "შეცვალა მომხმარებელმა {user}",
    "Deleted by {user}" : "წაშალა მომხმარებელმა {user}",
    "Restored by {user}" : "აღადგინა მომხმარებელმა {user}",
    "Renamed by {user}" : "სახელი გადაარქვა მომხმარებელმა {user}",
    "Moved by {user}" : "გადაიტანა მომხმარებელმა {user}",
    "\"remote user\"" : "\"დისტანციური მომხმარებელი\"",
    "You created {file}" : "თქვენ შექმენით {file}",
    "You created an encrypted file in {file}" : "შექმენით დაშიფრული ფაილი {file}-ში",
    "{user} created {file}" : "{user} მომხმარებელმა შექმნა {file}",
    "{user} created an encrypted file in {file}" : "{user} მომხმარებელმა შექმნა დაშიფრული ფაილი {file}-ში",
    "{file} was created in a public folder" : "{file} შეიქმნა საზოგადო დირექტორიაში",
    "You changed {file}" : "თქვენ შეცვალეთ {file}",
    "You changed an encrypted file in {file}" : "შეცვალეთ დაშიფრული ფაილი {file}-ში",
    "{user} changed {file}" : "{user} მომხმარებელმა შეცვალა {file}",
    "{user} changed an encrypted file in {file}" : "{user} მომხმარებელმა შეცვალა დაშიფრული ფაილი {file}-ში",
    "You deleted {file}" : "თქვენ წაშალეთ {file}",
    "You deleted an encrypted file in {file}" : "გააუქმეთ დაშიფრული ფაილი {file}-ში",
    "{user} deleted {file}" : "{user} მომხმარებელმა წაშალა {file}",
    "{user} deleted an encrypted file in {file}" : "{user} მომხმარებელმა გააუქმა დაშიფრული ფაილი {file}-ში",
    "You restored {file}" : "თქვენ აღადგინეთ {file}",
    "{user} restored {file}" : "{user} მომხმარებელმა განაახლა {file}",
    "You renamed {oldfile} to {newfile}" : "თქვენ გადაარქვით სახელი {oldfile}-ს {newfile}-ზე",
    "{user} renamed {oldfile} to {newfile}" : "{user}-მა გადაარქვა სახელი {oldfile}-ს {newfile}-ზე",
    "You moved {oldfile} to {newfile}" : "თქვენ გადაიტანეთ {oldfile} {newfile}-ად",
    "{user} moved {oldfile} to {newfile}" : "{user}-მა გადაიტანა {oldfile} {newfile}-ად",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ყველა ფაილი დაემატა ან ამოიშალა<strong>რჩეულებიდან</strong>",
    "All files" : "ყველა ფაილი",
    "Upload (max. %s)" : "ატვირთვა (მაქს. %s)",
    "Accept" : "მიღება",
    "in %s" : "%s-ში",
    "Change" : "შეცვლა",
    "Unknown error" : "უცნობი შეცდომა",
    "Show hidden files" : "დამალული ფაილების ჩვენება",
    "Additional settings" : "დამატებითი პარამეტრები",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Cancel" : "უარყოფა",
    "Create" : "შექმნა",
    "No files in here" : "აქ ფაილები არაა",
    "Upload some content or sync with your devices!" : "ატვირთეთ რამე ან მოახდინეთ სინქრონიზაცია თქვენს მოწყობილობებთან!",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ იქნა ნაპოვნი",
    "Select all" : "ყველას არჩევა",
    "Upload too large" : "ასატვირთი ფაილი ძალიან დიდია",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ფაილის ზომა რომლის ატვირთვასაც აპირებთ, აჭარბებს სერვერზე დაშვებულ მაქსიმუმს.",
    "No favorites yet" : "ჯერ რჩეულები არაა",
    "Files and folders you mark as favorite will show up here" : "აქ გამოჩნდებიან ფაილები და დირექტორიები, რომლებსაც მონიშნავთ რჩეულებად",
    "Deleted files" : "გაუქმებული ფაილები",
    "Shares" : "გაზიარებები",
    "Shared with others" : "გაზიარდა სხვებთან",
    "Shared with you" : "გაზიარდა თქვენთან",
    "Shared by link" : "გაზიარდა ბმულით",
    "Text file" : "ტექსტური ფაილი",
    "New text file.txt" : "ახალი ტექსტი file.txt",
    "Storage invalid" : "საცავი არასწორია",
    "Select" : "არჩევა",
    "You don’t have permission to upload or create files here" : "აქ ფაილების შექმნის ან ატვირთვის უფლება არ გაქვთ",
    "New" : "ახალი",
    "Copied!" : "დაკოპირდა!",
    "Unlimited" : "ულიმიტო",
    "%s used" : "%s მოხმარებულია",
    "%1$s of %2$s used" : "გამოყენებულია %1$s სულ %2$s-იდან ",
    "Settings" : "პარამეტრები"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-25.0.6.tgz: nextcloud/apps/files/l10n/ka_GE.js <==
OC.L10N.register(
    "files",
    {
    "File could not be found" : "ფაილი ვერ იქნა ნაპოვნი",
    "Move or copy" : "გადაიტანეთ ან დააკოპირეთ",
    "Download" : "ჩამოტვირთვა",
    "Delete" : "წაშლა",
    "Tags" : "ტეგები",
    "Home" : "სახლი",
    "Close" : "დახურვა",
    "Favorites" : "რჩეულები",
    "Could not create folder \"{dir}\"" : "დირექტორია \"{dir}\" ვერ შეიქმნა",
    "Upload cancelled." : "ატვირთვა შეჩერებულ იქნა.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "შეუძლებელია {filename}-ის ატვირთვა, რადგანაც ის დირექტორიაა ან გააჩნია 0 ბაიტი",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "არასაკმარისი თავისუფალი სივრცე, თქვენ ტვირთავთ {size1}-ს, მაგრამ მხოლოდ {size2}-ია დარჩენილი",
    "Target folder \"{dir}\" does not exist any more" : "დანიშნულების დირექტორია \"{dir}\" აღარ არსებობს",
    "Not enough free space" : "არასაკმარისი თავისუფალი სივრცე",
    "Uploading …" : "იტვირთება ...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} სულ {totalSize}-დან ({bitrate})",
    "Target folder does not exist any more" : "დანიშნულების დირექტორია აღარ არსებობს",
    "Error when assembling chunks, status code {status}" : "ნაჭრების შეგროვებისას წარმოიშვა შეცდომა, სტატუსის კოდი {status}",
    "Actions" : "მოქმედებები",
    "Rename" : "გადარქმევა",
    "Move" : "გადატანა",
    "Copy" : "კოპირება",
    "Delete file" : "გაუქმდეს ფაილი",
    "Delete folder" : "დირექტორიის გაუქმება",
    "Disconnect storage" : "საცავის გათიშვა",
    "Could not load info for file \"{file}\"" : "ფაილზე \"{file}\" ინფორმაცია ვერ ჩაიტვირთა",
    "Files" : "ფაილები",
    "Details" : "დეტალები",
    "Pending" : "მოცდის რეჟიმში",
    "Unable to determine date" : "თარიღის დადგენა შეუძლებელია",
    "This operation is forbidden" : "ეს ოპერაცია აკრძალულია",
    "This directory is unavailable, please check the logs or contact the administrator" : "დირექტორია ხელმიუწვდომელია, გთოხვთ შეამოწმოთ ლოგები ან დაუკავშირდეთ ადმინისტრატორს",
    "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
    "Could not move \"{file}\", target exists" : "\"{file}\"-ის გადატანა ვერ მოხერხდა, დანიშნულება არსებობს",
    "Could not move \"{file}\"" : "\"{file}\"-ის გადატანა ვერ მოხერხდა",
    "Could not copy \"{file}\", target exists" : "\"{file}\"-ის კოპირება ვერ მოხერხდა, დანიშნულება არსებობს",
    "Could not copy \"{file}\"" : "\"{file}\"-ის კოპირება ვერ მოხერხდა",
    "Copied {origin} inside {destination}" : "დაკოპირდა {origin} {destionation}-ში",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "დაკოპირდა {origin} და {nbfiles} სხვა ფაილი {destionation}-ში",
    "{newName} already exists" : "{newName} უკვე არსებობს",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" სახელი ვერ შეეცვალა, ის აღარ არსებობს",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "სახელი \"{targetName}\" დირექტორია \"{dir}\"-ში უკვე გამოყენებულია. გთხოვთ აირჩიოთ სხვა სახელი.",
    "Could not rename \"{fileName}\"" : "ფაილს \"{fileName}\" სახელი ვერ შეეცვალა",
    "Could not create file \"{file}\"" : "ფაილი \"{file}\" ვერ შეიქმნა",
    "Could not create file \"{file}\" because it already exists" : "ფაილი \"{file}\" ვერ შეიქმნა, ის უკვე არსებობს",
    "Could not create folder \"{dir}\" because it already exists" : "დირექტორია \"{dir}\" ვერ შეიქმნა, ის უკვე არსებობს",
    "Error deleting file \"{fileName}\"." : "ფიალის \"{fileName}\" წაშლისას წარმოიქმნა შეცდომა.",
    "No search results in other folders for {tag}{filter}{endtag}" : "ძიების შედეგები სხვა დირექტორიებში {tag}{filter}{endtag} არაა",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეცვლილია",
    "_%n folder_::_%n folders_" : ["%n დირექტორია","%n დირექტორია"],
    "_%n file_::_%n files_" : ["%n ფაილი","%n ფაილი"],
    "{dirs} and {files}" : "{dirs} და {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n დამალულის ჩათვლით","%n დამალულის ჩათვლით"],
    "_Uploading %n file_::_Uploading %n files_" : ["ვტვირთავთ %n ფაილს","ვტვირთავთ %n ფაილს"],
    "{used} of {quota} used" : "გამოყენებულია {used} სულ  {quota}-დან",
    "{used} used" : "გამოყენებულია {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" არასწორი ფაილის სახელია.",
    "File name cannot be empty." : "ფაილის სახელი არ შეიძლება იყოს ცარიელი.",
    "\"/\" is not allowed inside a file name." : "\"/\" ფაილის სახელში არაა ნებადართული.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" არაა დაშვებული ფაილის ტიპი",
    "View in folder" : "ჩვენება დირექტორიაში",
    "Path" : "მისამართი",
    "_%n byte_::_%n bytes_" : ["%n ბაიტი","%n ბაიტი"],
    "Favorited" : "დამატებულია რჩეულებში",
    "Favorite" : "რჩეული",
    "Copy direct link (only works for users who have access to this file/folder)" : "დააკოპირეთ პირდაპირი ბმული (მუშაობს მომხმარებლებისთვის, რომელთაც გააჩნიათ წვდომა ამ ფაილის/დირექტორიის მიმართ)",
    "New folder" : "ახალი დირექტორია",
    "Upload file" : "ფაილის ატვირთვა",
    "Recent" : "ახალი",
    "Not favorited" : "არაა დამატებული რჩეულებში",
    "Remove from favorites" : "რჩეულებიდან მოშორება",
    "Add to favorites" : "რჩეულებში დამატება",
    "An error occurred while trying to update the tags" : "ტეგების განახლების მცდელობისას წარმოიშვა შეცდომა",
    "Added to favorites" : "დაემატა რჩეულებში",
    "Removed from favorites" : "ამოიშალა რჩეულებიდან",
    "You added {file} to your favorites" : "თქვენ დაამატეთ {file}-ი რჩეულებში",
    "You removed {file} from your favorites" : "თქვენ ამოშალეთ {file}-ი თქვენი რჩეული ფაილებიდან",
    "File changes" : "ფაილის ცვლილებები",
    "Created by {user}" : "შექმნა მომხმარებელმა {user}",
    "Changed by {user}" : "შეცვალა მომხმარებელმა {user}",
    "Deleted by {user}" : "წაშალა მომხმარებელმა {user}",
    "Restored by {user}" : "აღადგინა მომხმარებელმა {user}",
    "Renamed by {user}" : "სახელი გადაარქვა მომხმარებელმა {user}",
    "Moved by {user}" : "გადაიტანა მომხმარებელმა {user}",
    "\"remote user\"" : "\"დისტანციური მომხმარებელი\"",
    "You created {file}" : "თქვენ შექმენით {file}",
    "You created an encrypted file in {file}" : "შექმენით დაშიფრული ფაილი {file}-ში",
    "{user} created {file}" : "{user} მომხმარებელმა შექმნა {file}",
    "{user} created an encrypted file in {file}" : "{user} მომხმარებელმა შექმნა დაშიფრული ფაილი {file}-ში",
    "{file} was created in a public folder" : "{file} შეიქმნა საზოგადო დირექტორიაში",
    "You changed {file}" : "თქვენ შეცვალეთ {file}",
    "You changed an encrypted file in {file}" : "შეცვალეთ დაშიფრული ფაილი {file}-ში",
    "{user} changed {file}" : "{user} მომხმარებელმა შეცვალა {file}",
    "{user} changed an encrypted file in {file}" : "{user} მომხმარებელმა შეცვალა დაშიფრული ფაილი {file}-ში",
    "You deleted {file}" : "თქვენ წაშალეთ {file}",
    "You deleted an encrypted file in {file}" : "გააუქმეთ დაშიფრული ფაილი {file}-ში",
    "{user} deleted {file}" : "{user} მომხმარებელმა წაშალა {file}",
    "{user} deleted an encrypted file in {file}" : "{user} მომხმარებელმა გააუქმა დაშიფრული ფაილი {file}-ში",
    "You restored {file}" : "თქვენ აღადგინეთ {file}",
    "{user} restored {file}" : "{user} მომხმარებელმა განაახლა {file}",
    "You renamed {oldfile} to {newfile}" : "თქვენ გადაარქვით სახელი {oldfile}-ს {newfile}-ზე",
    "{user} renamed {oldfile} to {newfile}" : "{user}-მა გადაარქვა სახელი {oldfile}-ს {newfile}-ზე",
    "You moved {oldfile} to {newfile}" : "თქვენ გადაიტანეთ {oldfile} {newfile}-ად",
    "{user} moved {oldfile} to {newfile}" : "{user}-მა გადაიტანა {oldfile} {newfile}-ად",
    "A file has been added to or removed from your <strong>favorites</strong>" : "ყველა ფაილი დაემატა ან ამოიშალა<strong>რჩეულებიდან</strong>",
    "All files" : "ყველა ფაილი",
    "Upload (max. %s)" : "ატვირთვა (მაქს. %s)",
    "Accept" : "მიღება",
    "in %s" : "%s-ში",
    "Select all" : "ყველას არჩევა",
    "Change" : "შეცვლა",
    "Unknown error" : "უცნობი შეცდომა",
    "No files in here" : "აქ ფაილები არაა",
    "Go back" : "უკან დაბრუნება",
    "Show hidden files" : "დამალული ფაილების ჩვენება",
    "Additional settings" : "დამატებითი პარამეტრები",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "კოპირება ბუფერში",
    "Cancel" : "უარყოფა",
    "Create" : "შექმნა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Upload some content or sync with your devices!" : "ატვირთეთ რამე ან მოახდინეთ სინქრონიზაცია თქვენს მოწყობილობებთან!",
    "No entries found in this folder" : "ამ დირექტორიაში შენატანები ვერ იქნა ნაპოვნი",
    "Upload too large" : "ასატვირთი ფაილი ძალიან დიდია",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ფაილის ზომა რომლის ატვირთვასაც აპირებთ, აჭარბებს სერვერზე დაშვებულ მაქსიმუმს.",
    "No favorites yet" : "ჯერ რჩეულები არაა",
    "Files and folders you mark as favorite will show up here" : "აქ გამოჩნდებიან ფაილები და დირექტორიები, რომლებსაც მონიშნავთ რჩეულებად",
    "Shares" : "გაზიარებები",
    "Shared with others" : "გაზიარდა სხვებთან",
    "Shared with you" : "გაზიარდა თქვენთან",
    "Shared by link" : "გაზიარდა ბმულით",
    "Text file" : "ტექსტური ფაილი",
    "New text file.txt" : "ახალი ტექსტი file.txt",
    "Storage invalid" : "საცავი არასწორია",
    "Select" : "არჩევა",
    "You don’t have permission to upload or create files here" : "აქ ფაილების შექმნის ან ატვირთვის უფლება არ გაქვთ",
    "New" : "ახალი",
    "Copied!" : "დაკოპირდა!",
    "Unlimited" : "ულიმიტო",
    "%s used" : "%s მოხმარებულია",
    "%1$s of %2$s used" : "გამოყენებულია %1$s სულ %2$s-იდან ",
    "Settings" : "პარამეტრები",
    "Deleted files" : "გაუქმებული ფაილები"
},
"nplurals=2; plural=(n!=1);");
